#!/bin/bash

SCRIPT_NAME="$(basename "$0")"

usage() {
    cat << EOF
Usage: ${SCRIPT_NAME}

${SCRIPT_NAME} cleans up UFM-HA cluster configuration and data on both HA nodes and restores original UFM files.

[*] NOTE: ${SCRIPT_NAME} requires SSH trust established between HA nodes.

EOF
}

parse_options() {
    short_opts="h"
    options=$(getopt -n ${SCRIPT_NAME} -o ${short_opts} -- "$@")
    if [ $? -ne 0 ]; then
      usage
      exit 1
    fi

    eval set -- "$options"
    while true
    do
        case "$1" in
            -h | --help)
                usage
                exit 0
                ;;
            --)
                shift
                break
                ;;
        esac
    done
}

cleanup_ha(){
    echo "Cleaning HA settings on master"
    /usr/local/bin/ufm_ha_cluster cleanup
    exit_code=$?; [ ${exit_code} -ne 0 ] && echo "- ERROR - Failed to cleanup HA settings on Main node" && return ${exit_code}

    standby_hostname=$(pcs status 2> /dev/null | grep -E '(Slaves|Unpromoted)' | awk -F: '{print $2}' | awk '{print $2}')
    echo "Cleaning HA settings on standby: ${standby_hostname}"
    ssh ${standby_hostname} "/usr/local/bin/ufm_ha_cluster cleanup"
    exit_code=$?; [ ${exit_code} -ne 0 ] && echo "- ERROR - Failed to cleanup HA settings  on Standby node" && return ${exit_code}
}

parse_options "$@"
cleanup_ha
