#!/bin/bash

SCRIPT_NAME="$(basename "$0")"
SCRIPT_DIR="$(dirname "$(readlink -f "$0")")"


usage() {
    cat << EOF
Usage: ${SCRIPT_NAME} [OPTIONS]

${SCRIPT_NAME} replace Standby node on HA cluster. Run this script ONLY once on the HA Master node.

[*] NOTE: ${SCRIPT_NAME} requires SSH trust established between HA nodes.

OPTIONS:
    --cluster-password            HA cluster password
    --master-ip                   Master node IP address
    --standby-ip                  new Standby node IP address
    -h | --help                  Show this message.

EOF
}

parse_options() {
    short_opts="h"
    long_opts="cluster-password:,master-ip:,standby-ip:,virtual-ip:,help"
    long_opts="cluster-password:,master-ip:,standby-ip:,help"
    options=$(getopt -n ${SCRIPT_NAME} -o ${short_opts} --long ${long_opts} -- "$@")
    if [ $? -ne 0 ]; then
      usage
      exit 1
    fi

    eval set -- "$options"
    while true
    do
        case "$1" in
            --cluster-password)
                cluster_pwd=$2
                shift 2
                ;;
            --master-ip)
                master_ip=$2
                shift 2
                ;;
            --standby-ip)
                standby_ip=$2
                shift 2
                ;;
            --virtual-ip)
                virtual_ip=$2
                shift 2
                ;;
            -h | --help)
                usage
                exit 0
                ;;
            --)
                shift
                break
                ;;
        esac
    done

    if [[ -z ${cluster_pwd} ]]; then
        echo "ERROR - Missing argument: cluster-password"
    fi

    if [[ -z ${master_ip} ]]; then
        echo "ERROR - Missing argument: master-ip"
        usage
        exit 1
    fi

    if [[ -z ${standby_ip} ]]; then
        echo "ERROR - Missing argument: standby-ip"
        usage
        exit 1
    fi

}

replace_ha(){
    /usr/local/bin/ufm_ha_cluster detach
    exit_code=$?; [ ${exit_code} -ne 0 ] && echo "- ERROR - Failed to disconnect  Standby node from cluster" && return ${exit_code}
    ssh ${standby_ip} "/usr/local/bin/ufm_ha_cluster set-password -p ${cluster_pwd}"
    exit_code=$?; [ ${exit_code} -ne 0 ] && echo "- ERROR - Failed to set password on Standby node" && return ${exit_code}

    ssh ${standby_ip} "/usr/local/bin/ufm_ha_cluster config -r standby -l ${standby_ip} -e ${master_ip} -p ${cluster_pwd}"
    exit_code=$?; [ ${exit_code} -ne 0 ] && echo "- ERROR - Failed to configure HA cluster on Standby node" && return ${exit_code}

    /usr/local/bin/ufm_ha_cluster attach -l ${master_ip} -e ${standby_ip} -p ${cluster_pwd}
    exit_code=$?; [ ${exit_code} -ne 0 ] && echo "- ERROR - Failed to replace the standby node in HA cluster." && return ${exit_code}
}

parse_options "$@"

echo "==================="
echo " Replace Standby Node"
echo "==================="
echo "Master IP:                ${master_ip}"
echo "Standby IP:               ${standby_ip}"

replace_ha
